@@ -58,6 +58,13 @@ fn main() {
     if windows {
         add_c_files(&mut cfg, "libgit2/src/win32".as_ref());
         cfg.define("STRSAFE_NO_DEPRECATE", None);
+
+        // libgit2's build system claims that forks like mingw-w64 of MinGW
+        // still want this define to use C99 stdio functions automatically.
+        // Apparently libgit2 breaks at runtime if this isn't here? Who knows!
+        if target.contains("gnu") {
+            cfg.define("__USE_MINGW_ANSI_STDIO", "1");
+        }
     } else {
         add_c_files(&mut cfg, "libgit2/src/unix".as_ref());
         cfg.flag("-fvisibility=hidden");
@@ -68,7 +75,10 @@ fn main() {
     features.push_str("#ifndef INCLUDE_features_h\n");
     features.push_str("#define INCLUDE_features_h\n");
     features.push_str("#define GIT_THREADS 1\n");
-    features.push_str("#define GIT_USE_NSEC 1\n");
+
+    if !target.contains("android") {
+        features.push_str("#define GIT_USE_NSEC 1\n");
+    }
 
     if target.contains("apple") {
         features.push_str("#define GIT_USE_STAT_MTIMESPEC 1\n");
